import { EventEmitter, OnInit } from '@angular/core';
import { LfI18n, LfStorage, PathBased } from '@lightweightform/core';
import * as i0 from "@angular/core";
/**
 * Abstract class for components that are toggleable and path based.
 */
export declare abstract class Toggleable extends PathBased implements OnInit {
    /**
     * Whether the toggleable element should start visible.
     */
    startVisible: boolean;
    /**
     * Event emitter which emits an event whenever the toggleable is set to be
     * shown.
     */
    _show: EventEmitter<void>;
    /**
     * Event emitter which emits an event whenever the toggleable is set to be
     * hidden.
     */
    _hide: EventEmitter<void>;
    protected _isVisible: boolean;
    constructor(parentPathBasedComponent: PathBased | null, lfStorage: LfStorage, lfI18n: LfI18n);
    /**
     * Whether the toggleable is visible.
     */
    get isVisible(): boolean;
    set isVisible(setVisible: boolean);
    ngOnInit(): void;
    /**
     * Show the toggleable element.
     */
    show(): void;
    /**
     * Hide the toggleable element.
     */
    hide(): void;
    /**
     * Toggle the visibility of the toggleable element.
     */
    toggle(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<Toggleable, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<Toggleable, never, never, { "startVisible": "startVisible"; }, { "_show": "show"; "_hide": "hide"; }, never>;
}
