import { OnInit } from '@angular/core';
import { LfI18n, LfRouter, LfStorage, PathBased } from '@lightweightform/core';
import { ValidationIssue } from '@lightweightform/storage';
import { MarkdownService } from 'ngx-markdown';
import * as i0 from "@angular/core";
/**
 * Protocol prefix used for LF links.
 */
export declare const LF_URL_PROTOCOL = "lf:";
/**
 * Validation message directive.
 */
export declare class ValidationIssueDirective extends PathBased implements OnInit {
    private lfRouter;
    private markdownService;
    constructor(parentPathBasedComponent: PathBased | null, lfStorage: LfStorage, lfI18n: LfI18n, lfRouter: LfRouter, markdownService: MarkdownService);
    /**
     * HTML string with the issue message to display.
     */
    get issueMessageHTML(): string;
    /**
     * Renderer capable of handling `lf://` links.
     */
    private get lfLinksRenderer();
    /**
     * Issue with message to display.
     */
    issue: ValidationIssue;
    /**
     * Default issue code associated with issues of a certain type.
     * @param type Type of the issue.
     * @returns Default issue code.
     */
    private static defaultCodeForType;
    _onClick(target: HTMLElement, button: number, ctrlKey: boolean, metaKey: boolean, shiftKey: boolean): boolean;
    /**
     * Label associated with the given path.
     * @param path Path from which to fetch label.
     * @returns Label of given path.
     */
    private labelOf;
    static ɵfac: i0.ɵɵFactoryDeclaration<ValidationIssueDirective, [{ optional: true; }, null, null, null, null]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ValidationIssueDirective, "lf-validation-issue, [lfValidationIssue]", ["lfValidationIssue"], { "issue": "issue"; }, {}, never>;
}
